2.0.0 (2024-01-10)
------------------

- Add support for Python 3.11 & 3.12
- Add support for Django 4.2 & 5.0
- Add support for Python 3.10
- Drop support for Python 3.6 & 3.7
- Drop support for Django 3.1
- Drop support for Django 2.2


1.4.1 (2021-06-24)
------------------

- Remove use of deprecated ugettext_lazy


1.4.0 (2021-06-02)
------------------

- Drop support for Python 2
- Drop support for Django 1.1, 2.0, 2.1 & 3.0
- Fix support for Django 3.1
- Add support for Python 3.9 & Django 3.2

1.3.0 (2020-08-12)
------------------

- Add support of Django 3.0 and 3.1.


Previous versions
-----------------

Changes in previous versions were not recorded. See Git history for
further details.
